@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 // System
@@ -25,27 +25,27 @@
 
 // QT
 #include <qgroupbox.h>
-#include <qcheckbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QCheckBox>
 #include <qpixmap.h>
-#include <qpushbutton.h>
+#include <QPushButton>
 #include <qradiobutton.h>
+#include <QResizeEvent>
 #include <qwmatrix.h>
 
 
 // KDE
-#include <kaboutapplication.h>
+#include <kaboutapplicationdialog.h>
 #include <kaboutdata.h>
 #include <kaction.h>
 #include <kapplication.h>
 #include <kbugreport.h>
 #include <kcolorbutton.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kglobalaccel.h>
-#include <kglobalsettings.h>
+#include <kcolorscheme.h>
 #include <kiconloader.h>
 #include <kinputdialog.h>
 #include <klocale.h>
@@ -53,7 +53,6 @@
 #include <kstandarddirs.h>
 
 // // KMix
-#include "colorwidget.h"
 #include "mixertoolbox.h"
 #include "kmixapplet.h"
 #include "kmixtoolbox.h"
@@ -66,10 +65,10 @@
 
 extern "C"
 {
-  KDE_EXPORT KPanelApplet* init(QWidget *parent, const QString& configFile)
+  KDE_EXPORT K3PanelApplet* init(QWidget *parent, const QString& configFile)
   {
-     KGlobal::locale()->insertCatalogue("kmix");
-     return new KMixApplet(configFile, KPanelApplet::Normal,
+     KGlobal::locale()->insertCatalog("kmix");
+     return new KMixApplet(configFile, K3PanelApplet::Normal,
                            parent, "kmixapplet");
   }
 }
@@ -77,30 +76,36 @@ extern "C"
 int KMixApplet::s_instCount = 0;
 //<Mixer> KMixApplet::Mixer::mixers();
 
-static const QColor highColor = KGlobalSettings::baseColor();
-static const QColor lowColor = KGlobalSettings::highlightColor();
+static const QColor highColor = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
+static const QColor lowColor = KColorScheme(QPalette::Active, KColorScheme::Selection).background().color();
 static const QColor backColor = "#000000";
 static const QColor mutedHighColor = "#FFFFFF";
 static const QColor mutedLowColor = "#808080";
 static const QColor mutedBackColor = "#000000";
 
 AppletConfigDialog::AppletConfigDialog( QWidget * parent, const char * name )
-   : KDialogBase( KDialogBase::Plain, QString::null,
-                  KDialogBase::Ok | KDialogBase::Apply | KDialogBase::Cancel,
-                  KDialogBase::Ok, parent, name, false, true)
+   : KDialog( parent)
 {
+   setObjectName(name);
+   setButtons( KDialog::Ok | KDialog::Apply | KDialog::Cancel );
+   setDefaultButton( Ok );
+   setModal( false );
+   showButtonSeparator( true );
    setPlainCaption(i18n("Configure - Mixer Applet"));
-   QFrame* page = plainPage();
+   QFrame* page = new QFrame(this);
+   setMainWidget( page );
    QVBoxLayout *topLayout = new QVBoxLayout(page);
    colorWidget = new ColorWidget(page);
    topLayout->addWidget(colorWidget);
    setUseCustomColors(false);
+   connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
+   connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
 }
 
 void AppletConfigDialog::slotOk()
 {
     slotApply();
-    KDialogBase::slotOk();
+    KDialog::accept();
 }
 
 void AppletConfigDialog::slotApply()
@@ -149,61 +154,57 @@ bool AppletConfigDialog::useCustomColors() const
 }
 
 
-KMixApplet::KMixApplet( const QString& configFile, Type t,
+KMixApplet::KMixApplet( const QString& configFile, K3PanelApplet::Type t,
                         QWidget *parent, const char *name )
 
-   : KPanelApplet( configFile, t, KPanelApplet::Preferences | KPanelApplet::ReportBug | KPanelApplet::About, parent, name ),
-     m_mixerWidget(0), m_errorLabel(0), m_pref(0),
-     m_aboutData( "kmix", I18N_NOOP("KMix Panel Applet"),
-                         APP_VERSION, "Mini Sound Mixer Applet", KAboutData::License_GPL,
-                         I18N_NOOP( "(c) 1996-2000 Christian Esken\n(c) 2000-2003 Christian Esken, Stefan Schimanski") )
+   : K3PanelApplet( configFile, t, K3PanelApplet::Preferences | K3PanelApplet::ReportBug | K3PanelApplet::About, parent ),
+     m_appletView(0), m_errorLabel(0), m_pref(0),
+     m_aboutData( "kmix", 0, ki18n("KMix Panel Applet"),
+                         APP_VERSION, ki18n("Mini Sound Mixer Applet"), KAboutData::License_GPL,
+                         ki18n( "(c) 1996-2000 Christian Esken\n(c) 2000-2003 Christian Esken, Stefan Schimanski") )
 {
-    setBackgroundOrigin(AncestorOrigin);
-    kdDebug(67100) << "KMixApplet::KMixApplet instancing Applet. Old s_instCount="<< s_instCount << " configfile=" << configFile << endl;
-    //kdDebug(67100) << "KMixApplet::KMixApplet()" << endl;
+   setObjectName(name);
+    kDebug(67100) << "KMixApplet::KMixApplet instancing Applet. Old s_instCount="<< s_instCount << " configfile=" << configFile;
+    //kDebug(67100) << "KMixApplet::KMixApplet()";
     _layout = new QHBoxLayout(this); // it will always only be one item in it, so we don't care whether it is HBox or VBox
 
     // init static vars
     if ( s_instCount == 0) {
-        Mixer::mixers().setAutoDelete( TRUE );
+        //  !!! TODO Mixer::mixers().setAutoDelete( true );
 	QString dummyStringHwinfo;
-	MixerToolBox::initMixer(Mixer::mixers(), false, dummyStringHwinfo);
-    }	
+	MixerToolBox::instance()->initMixer(false, dummyStringHwinfo);
+    }
     s_instCount++;
-    kdDebug(67100) << "KMixApplet::KMixApplet instancing Applet, s_instCount="<< s_instCount << endl;
-	
-    KGlobal::dirs()->addResourceType( "appicon", KStandardDirs::kde_default("data") + "kmix/pics" );
+    kDebug(67100) << "KMixApplet::KMixApplet instancing Applet, s_instCount="<< s_instCount;
+
+    KGlobal::dirs()->addResourceType( "appicon", "data", "kmix/pics" );
 
     loadConfig();
-	
+
 
     /********** find out to use which mixer ****************************************/
     _mixer = 0;
-    for (_mixer= Mixer::mixers().first(); _mixer!=0; _mixer=Mixer::mixers().next())
+    for ( int i=0; i< Mixer::mixers().count(); ++i )
     {
-      if ( _mixer->id() == _mixerId ) break;
+       Mixer *mixer = (Mixer::mixers())[i];
+       if ( mixer->id() == _mixerName ) {  // @todo Check the change: _mixer->  to   mixer->
+          _mixer = mixer;
+          break;
+       }
     }
-    if ( _mixer == 0 ) {
-      /* Until KMix V3.4-0 the mixerNumber (int) was stored. This was too complicated to handle, so we use an
-       * unique ID (_mixer->mixerId(). But in case when the user changes soundcards (or when upgrading from
-       * KMix 3.4-0 to a 3.4-1 or newer), we scan also for the soundcard name */
-      for (_mixer= Mixer::mixers().first(); _mixer!=0; _mixer=Mixer::mixers().next())
-      {
-	if ( _mixer->mixerName() == _mixerName ) break;
-      }
+
+    if ( _mixer==0 && Mixer::mixers().count() == 1 ) {
+        // No mixer was matching. But we still don't have to prompt the user, if
+        // there is card available.
+	_mixer = (Mixer::mixers())[0];
     }
-	
-    // don't prompt for a mixer if there is just one available
-    if ( !_mixer && Mixer::mixers().count() == 1 ) {
-	_mixer = Mixer::mixers().first();
-    }
-	
 
 
+    /*** Check, whether a Mixer could be selected automagically ******************/
     if ( _mixer == 0 )
     {
 	// No mixer set by user (kmixappletrc_*) and more than one to choose
-	// We do NOT know which mixer to use => ask the User
+	// We do NOT know which mixer to use => Ask the User
 	m_errorLabel = new QPushButton( i18n("Select Mixer"), this );
 	m_errorLabel->setGeometry(0, 0, m_errorLabel->sizeHint().width(),  m_errorLabel->sizeHint().height() );
 	resize( m_errorLabel->sizeHint() );
@@ -213,7 +214,7 @@ KMixApplet::KMixApplet( const QString& configFile, Type t,
 	// We know which mixer to use: Call positionChange(), which does all the creating
 	positionChange(position());
     }
-    m_aboutData.addCredit( I18N_NOOP( "For detailed credits, please refer to the About information of the KMix program" ) );
+    m_aboutData.addCredit( ki18n( "For detailed credits, please refer to the About information of the KMix program" ) );
 }
 
 KMixApplet::~KMixApplet()
@@ -232,73 +233,71 @@ KMixApplet::~KMixApplet()
 
 void KMixApplet::saveConfig()
 {
-    kdDebug(67100) << "KMixApplet::saveConfig()" << endl;
-    if ( m_mixerWidget != 0) {
-	//kdDebug(67100) << "KMixApplet::saveConfig() save" << endl;
-        KConfig *cfg = this->config();
-	//kdDebug(67100) << "KMixApplet::saveConfig() save cfg=" << cfg << endl;
-        cfg->setGroup( 0 );
-        cfg->writeEntry( "Mixer", _mixer->id() );
-        cfg->writeEntry( "MixerName", _mixer->mixerName() );
+    kDebug(67100) << "KMixApplet::saveConfig()";
+    if ( m_appletView != 0) {
+	//kDebug(67100) << "KMixApplet::saveConfig() save";
+	//kDebug(67100) << "KMixApplet::saveConfig() save cfg=" << cfg;
+        KConfigGroup grp( this->config(), "<default>");
+        grp.writeEntry( "Mixer", _mixer->id() );
+        grp.writeEntry( "MixerName", _mixer->id() );
 
-        cfg->writeEntry( "ColorCustom", _customColors );
+        grp.writeEntry( "ColorCustom", _customColors );
 
-        cfg->writeEntry( "ColorHigh", _colors.high.name() );
-        cfg->writeEntry( "ColorLow", _colors.low.name() );
-        cfg->writeEntry( "ColorBack", _colors.back.name() );
+        grp.writeEntry( "ColorHigh", _colors.high.name() );
+        grp.writeEntry( "ColorLow", _colors.low.name() );
+        grp.writeEntry( "ColorBack", _colors.back.name() );
 
-        cfg->writeEntry( "ColorMutedHigh", _colors.mutedHigh.name() );
-        cfg->writeEntry( "ColorMutedLow", _colors.mutedLow.name() );
-        cfg->writeEntry( "ColorMutedBack", _colors.mutedBack.name() );
+        grp.writeEntry( "ColorMutedHigh", _colors.mutedHigh.name() );
+        grp.writeEntry( "ColorMutedLow", _colors.mutedLow.name() );
+        grp.writeEntry( "ColorMutedBack", _colors.mutedBack.name() );
 
         //cfg->writeEntry( "ReversedDirection", reversedDir );
 
-        saveConfig( cfg, "Widget" );
-        cfg->sync();
+        saveConfig( config(), "Widget" );
+        config()->sync();
     }
 }
 
 
 void KMixApplet::loadConfig()
 {
-    kdDebug(67100) << "KMixApplet::loadConfig()" << endl;
-    KConfig *cfg = this->config();
-    cfg->setGroup(0);
-	
-    _mixerId = cfg->readEntry( "Mixer", "undef" );
-    _mixerName = cfg->readEntry( "MixerName", QString::null );
+    kDebug(67100) << "KMixApplet::loadConfig()";
+    KConfigGroup cfg(this->config(), "<default>");
 
-    _customColors = cfg->readBoolEntry( "ColorCustom", false );
-	
-    _colors.high = cfg->readColorEntry("ColorHigh", &highColor);
-    _colors.low = cfg->readColorEntry("ColorLow", &lowColor);
-    _colors.back = cfg->readColorEntry("ColorBack", &backColor);
+    _mixerId = cfg.readEntry( "Mixer", "undef" );
+    _mixerName = cfg.readEntry( "MixerName", QString());
 
-    _colors.mutedHigh = cfg->readColorEntry("ColorMutedHigh", &mutedHighColor);
-    _colors.mutedLow = cfg->readColorEntry("ColorMutedLow", &mutedLowColor);
-    _colors.mutedBack = cfg->readColorEntry("ColorMutedBack", &mutedBackColor);
+    _customColors = cfg.readEntry( "ColorCustom", false );
 
-    loadConfig( cfg, "Widget");
+    _colors.high = cfg.readEntry("ColorHigh", highColor);
+    _colors.low = cfg.readEntry("ColorLow", lowColor);
+    _colors.back = cfg.readEntry("ColorBack", backColor);
+
+    _colors.mutedHigh = cfg.readEntry("ColorMutedHigh", mutedHighColor);
+    _colors.mutedLow = cfg.readEntry("ColorMutedLow", mutedLowColor);
+    _colors.mutedBack = cfg.readEntry("ColorMutedBack", mutedBackColor);
+
+    loadConfig( this->config(), "Widget");
 }
 
 
-void KMixApplet::loadConfig( KConfig *config, const QString &grp )
+void KMixApplet::loadConfig( KConfig *config, const QString& /*grp*/ )
 {
-    if ( m_mixerWidget ) {
-	//config->setGroup( grp );
-	KMixToolBox::loadConfig(m_mixerWidget->_mdws, config, grp, "PanelApplet" );
+    if ( m_appletView ) {
+	KMixToolBox::loadView(m_appletView, config );
     }
 }
 
 
 void KMixApplet::saveConfig( KConfig *config, const QString &grp )
 {
-    if ( m_mixerWidget ) {
-	config->setGroup( grp );
+    if ( m_appletView ) {
 	// Write mixer name. It cannot be changed in the Mixer instance,
 	// it is only saved for diagnostical purposes (analyzing the config file).
-	config->writeEntry("Mixer_Name_Key", _mixer->mixerName());
-	KMixToolBox::saveConfig(m_mixerWidget->_mdws, config, grp, "PanelApplet" );
+	KConfigGroup cg(config, grp );
+	cg.writeEntry("Mixer_Name_Key", _mixer->id());
+
+	KMixToolBox::saveView(m_appletView, config );
     }
 }
 
@@ -310,22 +309,21 @@ void KMixApplet::selectMixer()
 {
    QStringList lst;
 
-   int n=1;
-   for (Mixer *mixer=Mixer::mixers().first(); mixer!=0; mixer=Mixer::mixers().next())
+   for ( int i=0; i< Mixer::mixers().count(); ++i )
    {
-      QString s;
-      s.sprintf("%i. %s", n, mixer->mixerName().ascii());
-      lst << s;
-      n++;
+       Mixer *mixer = (Mixer::mixers())[i];
+       QString s;
+       s.sprintf("%i. %s", (i+1), mixer->id().toAscii().data());
+       lst << s;
    }
 
-   bool ok = FALSE;
+   bool ok = false;
    QString res = KInputDialog::getItem( i18n("Mixers"),
                                         i18n("Available mixers:"),
-					lst, 1, FALSE, &ok, this );
+					lst, 1, false, &ok, this );
    if ( ok )
    {
-      Mixer *mixer = Mixer::mixers().at( lst.findIndex( res ) );
+      Mixer *mixer = Mixer::mixers().at( lst.indexOf( res ) );
       if (!mixer)
          KMessageBox::sorry( this, i18n("Invalid mixer entered.") );
       else
@@ -345,7 +343,7 @@ void KMixApplet::selectMixer()
 
 void KMixApplet::about()
 {
-    KAboutApplication aboutDlg(&m_aboutData);
+    KAboutApplicationDialog aboutDlg(&m_aboutData);
     aboutDlg.exec();
 }
 
@@ -354,34 +352,36 @@ void KMixApplet::help()
 }
 
 
-void KMixApplet::positionChange(Position pos) {
+void KMixApplet::positionChange(K3PanelApplet::Position pos) {
     orientationChange( orientation() );
-    QResizeEvent e( size(), size() ); // from KPanelApplet::positionChange
-    resizeEvent( &e ); // from KPanelApplet::positionChange
-    
+    QResizeEvent e( size(), size() ); // from K3PanelApplet::positionChange
+    resizeEvent( &e ); // from K3PanelApplet::positionChange
+
     if ( m_errorLabel == 0) {
 	// do this only after we deleted the error label
-	if (m_mixerWidget) {
+	if (m_appletView) {
 	    saveConfig(); // save the applet before recreating it
-	    _layout->remove(m_mixerWidget);
-	    delete m_mixerWidget;
+	    _layout->removeWidget(m_appletView);
+	    delete m_appletView;
 	}
-	m_mixerWidget = new ViewApplet( this, _mixer->name(), _mixer, 0, pos );
-	connect ( m_mixerWidget, SIGNAL(appletContentChanged()), this, SLOT(updateGeometrySlot()) );
-	m_mixerWidget->createDeviceWidgets();
-	_layout->add(m_mixerWidget);
+ 	/**@todo Add View stuff to KMixApplet / ViewApplet */
+	m_appletView = new ViewApplet( this, _mixer->id().toAscii().data(), _mixer, 0,
+                (GUIProfile*)0, pos );
+	connect ( m_appletView, SIGNAL(appletContentChanged()), this, SLOT(updateGeometrySlot()) );
+	m_appletView->createDeviceWidgets();
+	_layout->addWidget(m_appletView);
 	_layout->activate();
-	
+
 	loadConfig();
 	setColors();
-	
+
 	const QSize panelAppletConstrainedSize = sizeHint();
-	m_mixerWidget->setGeometry( 0, 0, panelAppletConstrainedSize.width(), panelAppletConstrainedSize.height() );
+	m_appletView->setGeometry( 0, 0, panelAppletConstrainedSize.width(), panelAppletConstrainedSize.height() );
 	resize( panelAppletConstrainedSize.width(), panelAppletConstrainedSize.height() );
 	//setFixedSize(panelAppletConstrainedSize.width(), panelAppletConstrainedSize.height() );
-	//kdDebug(67100) << "KMixApplet::positionChange(). New MDW is at " << panelAppletConstrainedSize << endl;
-	m_mixerWidget->show();
-	//connect( _mixer, SIGNAL(newVolumeLevels()), m_mixerWidget, SLOT(refreshVolumeLevels()) );
+	//kDebug(67100) << "KMixApplet::positionChange(). New MDW is at " << panelAppletConstrainedSize;
+	m_appletView->show();
+	//connect( _mixer, SIGNAL(controlChanged()), m_appletView, SLOT(refreshVolumeLevels()) );
     }
 }
 
@@ -389,23 +389,23 @@ void KMixApplet::positionChange(Position pos) {
 /************* GEOMETRY STUFF START ********************************/
 void KMixApplet::resizeEvent(QResizeEvent *e)
 {
-    //kdDebug(67100) << "KMixApplet::resizeEvent(). New MDW is at " << e->size() << endl;
+    //kDebug(67100) << "KMixApplet::resizeEvent(). New MDW is at " << e->size();
 
-    if ( position() == KPanelApplet::pLeft || position() == KPanelApplet::pRight ) {
-        if ( m_mixerWidget ) m_mixerWidget->resize(e->size().width(),m_mixerWidget->height());
+    if ( position() == K3PanelApplet::Left || position() == K3PanelApplet::Right ) {
+        if ( m_appletView ) m_appletView->resize(e->size().width(),m_appletView->height());
         if ( m_errorLabel  ) m_errorLabel ->resize(e->size().width(),m_errorLabel ->height());
     }
     else {
-        if ( m_mixerWidget ) m_mixerWidget->resize(m_mixerWidget->width(), e->size().height());
+        if ( m_appletView ) m_appletView->resize(m_appletView->width(), e->size().height());
         if ( m_errorLabel  ) m_errorLabel ->resize(m_errorLabel ->width() ,e->size().height());
     }
 
 
     // resizing changes our own sizeHint(), because we must take the new PanelSize in account.
     // So updateGeometry() is amust for us.
-    //kdDebug(67100) << "KMixApplet::resizeEvent(). UPDATE GEOMETRY" << endl;
+    //kDebug(67100) << "KMixApplet::resizeEvent(). UPDATE GEOMETRY";
     updateGeometry();
-    //kdDebug(67100) << "KMixApplet::resizeEvent(). EMIT UPDATE LAYOUT" << endl;
+    //kDebug(67100) << "KMixApplet::resizeEvent(). EMIT UPDATE LAYOUT";
     emit updateLayout();
 }
 
@@ -415,33 +415,30 @@ void KMixApplet::updateGeometrySlot() {
 
 
 QSize KMixApplet::sizeHint() const {
-    //kdDebug(67100) << "KMixApplet::sizeHint()\n";
+    //kDebug(67100) << "KMixApplet::sizeHint()\n";
     QSize qsz;
     if ( m_errorLabel !=0 ) {
 	qsz = m_errorLabel->sizeHint();
     }
-    else if (  m_mixerWidget != 0) {
-	qsz = m_mixerWidget->sizeHint();
+    else if (  m_appletView != 0) {
+	qsz = m_appletView->sizeHint();
     }
     else {
-	// During construction of m_mixerWidget or if something goes wrong:
+	// During construction of m_appletView or if something goes wrong:
 	// Return something that should resemble our former sizeHint().
 	qsz = size();
     }
-    //kdDebug(67100) << "KMixApplet::sizeHint() leftright =" << qsz << "\n";
     return qsz;
 }
 
 /**
-   We need widthForHeight() and heigthForWidth() only because KPanelApplet::updateLayout does relayouts
+   We need widthForHeight() and heigthForWidth() only because K3PanelApplet::updateLayout does relayouts
    using this method. Actually we ignore the passed paramater and just return our preferred size.
 */
 int KMixApplet::widthForHeight(int) const {
-    //kdDebug(67100) << "KMixApplet::widthForHeight() = " << sizeHint().width() << endl;
     return sizeHint().width();
 }
 int KMixApplet::heightForWidth(int) const {
-    //kdDebug(67100) << "KMixApplet::heightForWidth() = " << sizeHint().height() << endl;
     return sizeHint().height();
 }
 
@@ -449,13 +446,10 @@ int KMixApplet::heightForWidth(int) const {
 
 
 QSizePolicy KMixApplet::sizePolicy() const {
-    //    return QSizePolicy(QSizePolicy::Preferred,QSizePolicy::Preferred);
     if ( orientation() == Qt::Vertical ) {
-	//kdDebug(67100) << "KMixApplet::sizePolicy=(Ignored,Fixed)\n";
         return QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
     }
     else {
-	//kdDebug(67100) << "KMixApplet::sizePolicy=(Fixed,Ignored)\n";
         return QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
    }
 }
@@ -507,12 +501,12 @@ void KMixApplet::applyPreferences()
     m_pref->activeColors(_colors.high     , _colors.low     , _colors.back);
     m_pref->mutedColors (_colors.mutedHigh, _colors.mutedLow, _colors.mutedBack);
     _customColors = m_pref->useCustomColors();
-    if (!m_mixerWidget)
+    if (!m_appletView)
         return;
 
     /*
-    QSize si = m_mixerWidget->size();
-    m_mixerWidget->resize( si );
+    QSize si = m_appletView->size();
+    m_appletView->resize( si );
     */
     setColors();
     saveConfig();
@@ -521,9 +515,9 @@ void KMixApplet::applyPreferences()
 void KMixApplet::paletteChange ( const QPalette &) {
     if ( ! _customColors ) {
 	// We take over Colors from paletteChange(), if the user has not set custom colors.
-	// ignore the given QPalette and use the values from KGlobalSettings instead
-	_colors.high = KGlobalSettings::highlightColor();
-	_colors.low  = KGlobalSettings::baseColor();
+	// ignore the given QPalette and use the values from KColorScheme instead
+	_colors.high = KColorScheme(QPalette::Active, KColorScheme::Selection).background().color();
+	_colors.low  = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
 	_colors.back = backColor;
 	setColors( _colors );
     }
@@ -547,12 +541,13 @@ void KMixApplet::setColors()
 
 void KMixApplet::setColors( const Colors &color )
 {
-    if ( m_mixerWidget == 0 ) {
+    if ( m_appletView == 0 ) {
         // can happen for example after a paletteChange()
         return;
     }
-    QPtrList<QWidget> &mdws = m_mixerWidget->_mdws;
-    for ( QWidget* qmdw=mdws.first(); qmdw != 0; qmdw=mdws.next() ) {
+    QList<QWidget *> &mdws = m_appletView->_mdws;
+    for ( int i=0; i < mdws.count(); ++i ) {
+        QWidget* qmdw = mdws[i];
 	if ( qmdw->inherits("MixDeviceWidget") ) { // -<- temporary check. Later we *know* that it is correct
 	    static_cast<MixDeviceWidget*>(qmdw)->setColors( color.high, color.low, color.back );
 	    static_cast<MixDeviceWidget*>(qmdw)->setMutedColors( color.mutedHigh, color.mutedLow, color.mutedBack );
